==> jc-1.4.0.tar.gz: java/security/cert/Certificate__24CertificateRep.h <==
// public class java.security.cert.Certificate$CertificateRep

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bd5e3e870876e966 java_security_cert_Certificate__24CertificateRep

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_Certificate__24CertificateRep_H_
#define _JC_java_security_cert_Certificate__24CertificateRep_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_cert_Certificate__24CertificateRep$sub_refs	_jc_java_security_cert_Certificate__24CertificateRep$sub_refs;
typedef struct _jc_java_security_cert_Certificate__24CertificateRep$sub_nonrefs	_jc_java_security_cert_Certificate__24CertificateRep$sub_nonrefs;
typedef struct _jc_java_security_cert_Certificate__24CertificateRep$refs	_jc_java_security_cert_Certificate__24CertificateRep$refs;
typedef struct _jc_java_security_cert_Certificate__24CertificateRep$nonrefs	_jc_java_security_cert_Certificate__24CertificateRep$nonrefs;
typedef struct _jc_java_security_cert_Certificate__24CertificateRep$object	_jc_java_security_cert_Certificate__24CertificateRep$object;

typedef struct _jc_java_security_cert_Certificate__24CertificateRep$fields_struct	_jc_java_security_cert_Certificate__24CertificateRep$fields_struct;
typedef const struct _jc_java_security_cert_Certificate__24CertificateRep$vmethods	_jc_java_security_cert_Certificate__24CertificateRep$vmethods;
typedef const struct _jc_java_security_cert_Certificate__24CertificateRep$vtable	_jc_java_security_cert_Certificate__24CertificateRep$vtable;
typedef const struct _jc_java_security_cert_Certificate__24CertificateRep$vtype	_jc_java_security_cert_Certificate__24CertificateRep$vtype;

// Class fields structure
struct _jc_java_security_cert_Certificate__24CertificateRep$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_cert_Certificate__24CertificateRep$fields_struct _jc_java_security_cert_Certificate__24CertificateRep$class_fields;

// Constructors
extern void _jc_java_security_cert_Certificate__24CertificateRep$method$_init$8978305ea064370f(_jc_env *, struct _jc_java_security_cert_Certificate__24CertificateRep$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_cert_Certificate__24CertificateRep$method$readResolve$3c2bccd3a831d3ae(_jc_env *, struct _jc_java_security_cert_Certificate__24CertificateRep$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_Certificate__24CertificateRep$method_info$readResolve$3c2bccd3a831d3ae;

// Virtual methods structure
struct _jc_java_security_cert_Certificate__24CertificateRep$vmethods {
	struct _jc_java_lang_Object$object	*(*readResolve$3c2bccd3a831d3ae)(_jc_env *, struct _jc_java_security_cert_Certificate__24CertificateRep$object *);
};

// Vtable
struct _jc_java_security_cert_Certificate__24CertificateRep$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_Certificate__24CertificateRep$vmethods	java_security_cert_Certificate__24CertificateRep;
};

// Vtype
struct _jc_java_security_cert_Certificate__24CertificateRep$vtype {
	_jc_type			type;
	_jc_java_security_cert_Certificate__24CertificateRep$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_Certificate__24CertificateRep$sub_refs {
	struct _jc_java_lang_String$object	*type;
	_jc_byte_array	*data;
};

// Reference instance fields (object)
struct _jc_java_security_cert_Certificate__24CertificateRep$refs {
    _jc_java_security_cert_Certificate__24CertificateRep$sub_refs	java_security_cert_Certificate__24CertificateRep;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_Certificate__24CertificateRep$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_Certificate__24CertificateRep$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_Certificate__24CertificateRep$sub_nonrefs	java_security_cert_Certificate__24CertificateRep;
};

// Object instance structure
struct _jc_java_security_cert_Certificate__24CertificateRep$object {
	_jc_java_security_cert_Certificate__24CertificateRep$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_Certificate__24CertificateRep$vtype	*vtype;
	_jc_java_security_cert_Certificate__24CertificateRep$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_Certificate__24CertificateRep$vtype _jc_java_security_cert_Certificate__24CertificateRep$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_Certificate__24CertificateRep, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_Certificate__24CertificateRep$class_object;

#endif	/* _JC_java_security_cert_Certificate__24CertificateRep_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/Certificate__24CertificateRep.h <==
// public class java.security.cert.Certificate$CertificateRep

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bd5e3e870876e966 java_security_cert_Certificate__24CertificateRep

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_Certificate__24CertificateRep_H_
#define _JC_java_security_cert_Certificate__24CertificateRep_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_cert_Certificate__24CertificateRep$sub_refs	_jc_java_security_cert_Certificate__24CertificateRep$sub_refs;
typedef struct _jc_java_security_cert_Certificate__24CertificateRep$sub_nonrefs	_jc_java_security_cert_Certificate__24CertificateRep$sub_nonrefs;
typedef struct _jc_java_security_cert_Certificate__24CertificateRep$refs	_jc_java_security_cert_Certificate__24CertificateRep$refs;
typedef struct _jc_java_security_cert_Certificate__24CertificateRep$nonrefs	_jc_java_security_cert_Certificate__24CertificateRep$nonrefs;
typedef struct _jc_java_security_cert_Certificate__24CertificateRep$object	_jc_java_security_cert_Certificate__24CertificateRep$object;

typedef struct _jc_java_security_cert_Certificate__24CertificateRep$fields_struct	_jc_java_security_cert_Certificate__24CertificateRep$fields_struct;
typedef const struct _jc_java_security_cert_Certificate__24CertificateRep$vmethods	_jc_java_security_cert_Certificate__24CertificateRep$vmethods;
typedef const struct _jc_java_security_cert_Certificate__24CertificateRep$vtable	_jc_java_security_cert_Certificate__24CertificateRep$vtable;
typedef const struct _jc_java_security_cert_Certificate__24CertificateRep$vtype	_jc_java_security_cert_Certificate__24CertificateRep$vtype;

// Class fields structure
struct _jc_java_security_cert_Certificate__24CertificateRep$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_cert_Certificate__24CertificateRep$fields_struct _jc_java_security_cert_Certificate__24CertificateRep$class_fields;

// Constructors
extern void _jc_java_security_cert_Certificate__24CertificateRep$method$_init$8978305ea064370f(_jc_env *, struct _jc_java_security_cert_Certificate__24CertificateRep$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_cert_Certificate__24CertificateRep$method$readResolve$3c2bccd3a831d3ae(_jc_env *, struct _jc_java_security_cert_Certificate__24CertificateRep$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_Certificate__24CertificateRep$method_info$readResolve$3c2bccd3a831d3ae;

// Virtual methods structure
struct _jc_java_security_cert_Certificate__24CertificateRep$vmethods {
	struct _jc_java_lang_Object$object	*(*readResolve$3c2bccd3a831d3ae)(_jc_env *, struct _jc_java_security_cert_Certificate__24CertificateRep$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_Certificate__24CertificateRep$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_Certificate__24CertificateRep$vmethods	java_security_cert_Certificate__24CertificateRep;
};

// Vtype
struct _jc_java_security_cert_Certificate__24CertificateRep$vtype {
	_jc_type			type;
	_jc_java_security_cert_Certificate__24CertificateRep$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_Certificate__24CertificateRep$sub_refs {
	struct _jc_java_lang_String$object	*type;
	_jc_byte_array	*data;
};

// Reference instance fields (object)
struct _jc_java_security_cert_Certificate__24CertificateRep$refs {
    _jc_java_security_cert_Certificate__24CertificateRep$sub_refs	java_security_cert_Certificate__24CertificateRep;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_Certificate__24CertificateRep$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_Certificate__24CertificateRep$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_Certificate__24CertificateRep$sub_nonrefs	java_security_cert_Certificate__24CertificateRep;
};

// Object instance structure
struct _jc_java_security_cert_Certificate__24CertificateRep$object {
	_jc_java_security_cert_Certificate__24CertificateRep$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_Certificate__24CertificateRep$vtype	*vtype;
	_jc_java_security_cert_Certificate__24CertificateRep$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_Certificate__24CertificateRep$vtype _jc_java_security_cert_Certificate__24CertificateRep$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_Certificate__24CertificateRep, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_Certificate__24CertificateRep$class_object;

#endif	/* _JC_java_security_cert_Certificate__24CertificateRep_H_ */
